from os import getenv
import hvac
from .logger import get_logger


def _get_client(vault_url=None, vault_token=None):
    logger = get_logger(__name__)
    vault_url = getenv("VAULT_URL", vault_url)
    vault_token = getenv("VAULT_TOKEN", vault_token)
    if not vault_url:
        logger.error(
            "vault_url argument is not provided and VAULT_URL is not present in the environment"
        )
        return None
    if not api_key:
        logger.error(
            "vault_token argument is not provided and VAULT_TOKEN is not present in the environment"
        )
        return None
    client = hvac.Client(url=vault_url, token=vault_token)
    if client.is_authenticated():
        return client
    return None


def get_vault_secrets(path="", vault_url=None, vault_token=None):
    """get vault secrets for the path

    :param path: vault secrets path
    :type path: str
    :param vault_url: vault server url. If vault_url is none, VAULT_URL environment value will be assigned.
    :type vault_url: str
    :param vault_token: vault user access token. If vault_token is none, VAULT_TOKEN environment value will be assigned.
    :type vault_token: str
    :return: List(Dict[str, Any]) if successful, `None` otherwise
    """
    logger = get_logger(__name__)
    client = _get_client(vault_url=vault_url, vault_token=vault_token)
    if client is None:
        return None
    try:
        secrets = client.read(path)
        if "data" in secrets:
            secrets["data"]
    except Exception as e:
        logger.error(f"Got an error: {e.message}")
        return None
    return None



from os import getenv
from jira import JIRA
from .logger import get_logger
from jira.exceptions import JIRAError


def _get_client(api_server=None, api_user=None, api_key=None):
    logger = get_logger(__name__)
    api_user = getenv("JIRA_API_USER", api_user)
    api_key = getenv("JIRA_API_KEY", api_key)
    if not api_user:
        logger.error(
            "api_user argument is not provided and JIRA_API_USER is not present in the environment"
        )
        return None
    if not api_key:
        logger.error(
            "api_key argument is not provided and JIRA_API_KEY is not present in the environment"
        )
        return None
    return JIRA(server=api_server, basic_auth=(api_user, api_key))


def create_jira_issue(
    fields={}, api_server="https://jira.atlassian.com", api_user=None, api_key=None
):
    """creates a issue on the jira server

    :param fields: issue fields e.g) {'project': {'id': 123}, 'summary': 'New issue from jira-python', 'description': 'Look into this one', 'issuetype': {'name': 'Bug'}}
    :type fields: Dict[str, Any]
    :param api_server: jira api server url(default: https://jira.atlassian.com)
    :type api_server: str
    :param api_user: jira api user. If api_user is none, JIRA_API_USER environment value will be assigned.
    :type api_user: str
    :param api_key: jira user api key. If api_key is none, JIRA_API_KEY environment value will be assigned.
    :type api_key: str
    :return: `jira.Issue` if successful, `None` otherwise
    """
    logger = get_logger(__name__)
    jira = _get_client(api_server=api_server, api_user=api_user, api_key=api_key)
    if jira is None:
        return None
    try:
        issue = jira.create_issue(fields=fields)
    except JIRAError as e:
        logger.error(f"Got an error: {e.status_code} {e.text}")
        return None
    return issue


def create_jira_issues(
    issue_list=[], api_server="https://jira.atlassian.com", api_user=None, api_key=None
):
    """creates multiple issues on the jira server

    :param issue_list: issue list e.g) [{'project': {'id': 123}, 'summary': 'New issue from jira-python', 'description': 'Look into this one', 'issuetype': {'name': 'Bug'}}]
    :type fields: List[Dict[str, Any]]
    :param api_server: jira api server url(default: https://jira.atlassian.com)
    :type api_server: str
    :param api_user: jira api user. If api_user is none, JIRA_API_USER environment value will be assigned.
    :type api_user: str
    :param api_key: jira user api key. If api_key is none, JIRA_API_KEY environment value will be assigned.
    :type api_key: str
    :return: `jira.Issue` if successful, `None` otherwise
    """
    logger = get_logger(__name__)
    jira = _get_client(api_server=api_server, api_user=api_user, api_key=api_key)
    if jira is None:
        return None
    try:
        issues = jira.create_issues(field_list=issue_list)
    except JIRAError as e:
        logger.error(f"Got an error: {e.status_code} {e.text}")
        return None
    return issues


def update_jira_issue(
    jira_id,
    fields={},
    notify=True,
    api_server="https://jira.atlassian.com",
    api_user=None,
    api_key=None,
):
    """updates the issue on the jira server

    :param jira_id: jira id of the issue
    :type jira_id: str
    :param fields: issue fields e.g) {'summary': 'New issue from jira-python', 'description': 'Look into this one'}
    :type fields: Dict[str, Any]
    :param notify: should suppress notifications of the update
    :type notify: bool
    :param api_server: jira api server url(default: https://jira.atlassian.com)
    :type api_server: str
    :param api_user: jira api user. If api_user is none, JIRA_API_USER environment value will be assigned.
    :type api_user: str
    :param api_key: jira user api key. If api_key is none, JIRA_API_KEY environment value will be assigned.
    :type api_key: str
    :return: `jira.Issue` if successful, `None` otherwise
    """
    logger = get_logger(__name__)
    jira = _get_client(api_server=api_server, api_user=api_user, api_key=api_key)
    if jira is None:
        return None
    try:
        issue = jira.issue(jira_id)
        issue.update(fields=fields, notify=notify)
    except JIRAError as e:
        logger.error(f"Got an error: {e.status_code} {e.text}")
        return None
    return issue


def delete_jira_issue(
    jira_id,
    delete_subtasks=False,
    api_server="https://jira.atlassian.com",
    api_user=None,
    api_key=None,
):
    """deletes the issue on the jira server

    :param jira_id: jira id of the issue
    :type jira_id: str
    :param delete_subtasks: if the issue has subtasks, this argument must be set to true for the call to succeed.
    :type delete_subtasks: bool
    :param api_server: jira api server url(default: https://jira.atlassian.com)
    :type api_server: str
    :param api_user: jira api user. If api_user is none, JIRA_API_USER environment value will be assigned.
    :type api_user: str
    :param api_key: jira user api key. If api_key is none, JIRA_API_KEY environment value will be assigned.
    :type api_key: str
    :return: `True` if successful, `None` otherwise
    """
    logger = get_logger(__name__)
    jira = _get_client(api_server=api_server, api_user=api_user, api_key=api_key)
    if jira is None:
        return None
    try:
        issue = jira.issue(jira_id)
        issue.delete(deleteSubtasks=delete_subtasks)
    except JIRAError as e:
        logger.error(f"Got an error: {e.status_code} {e.text}")
        return None
    return True



#!/usr/bin/env python
"""Setup script for common """
import os.path
from setuptools import setup

# The directory containing this file
HERE = os.path.abspath(os.path.dirname(__file__))

# The text of the README file
with open(os.path.join(HERE, "README.md")) as fid:
    README = fid.read()

folder = os.path.dirname(os.path.realpath(__file__))
requirementPath = folder + "/tkcommon/requirements.txt"
install_requires = []
# The text of the requirements.txt
if os.path.isfile(requirementPath):
    with open(requirementPath) as f:
        install_requires = f.read().splitlines()

# This call to setup() does all the work
setup(
    name="tkcommon",
    version="1.0.1",
    description="tkcommon is a collection of small Python functions and classes for building scripts and internal tools.",
    long_description=README,
    long_description_content_type="text/markdown",
    url="https://bitbucket.org/tekion/tkcommon",
    author="Vinoth Kumar",
    author_email="vinothkumarj@tekion.com",
    python_requires=">3.5.2",
    packages=["tkcommon"],
    package_dir={"tkcommon": "tkcommon/"},
    include_package_data=True,
    install_requires=install_requires,
)
